@@ -11,17 +11,25 @@ fn main() {
         exit(1);
     });
     let input_path = Path::new(&input).display().to_string();
-
-    // add pak if it's not specified.
     if !input_path.ends_with(".pak") {
         eprintln!("File must be ended with .pak");
         exit(1);
     }
 
     let pak = EtFileSystem::read(&input_path);
-
-    let file_list = pak.get_files();
-    for file in file_list {
-        println!("{}", file);
+    let query = args.next();
+    match query {
+        Some(q) => {
+            let file_list = pak.find_files(&q);
+            for file in file_list {
+                println!("{}", file);
+            }
+        }
+        None => {
+            let file_list = pak.get_files();
+            for file in file_list {
+                println!("{}", file);
+            }
+        }
     }
 }
